Index: include/core/SkCanvas.h |
diff --git a/include/core/SkCanvas.h b/include/core/SkCanvas.h |
index 26458696bc4d81a4b1a9b304aa847616e93c011a..97aa3c7d8e343e06a1464615fb6edc788afc8148 100644 |
--- a/include/core/SkCanvas.h |
+++ b/include/core/SkCanvas.h |
@@ -419,11 +419,18 @@ public: |
*/ |
void scale(SkScalar sx, SkScalar sy); |
/** Preconcat the current matrix with the specified rotation. |
@param degrees The amount to rotate, in degrees |
*/ |
void rotate(SkScalar degrees); |
+ /** Preconcat the current matrix with the specified rotation about a given point. |
+ @param degrees The amount to rotate, in degrees |
+ @param px The x coordinate of the point to rotate about. |
+ @param py The y coordinate of the point to rotate about. |
+ */ |
+ void rotate(SkScalar degrees, SkScalar px, SkScalar py); |
+ |
/** Preconcat the current matrix with the specified skew. |
@param sx The amount to skew in X |
@param sy The amount to skew in Y |
@@ -419,11 +419,18 @@ public: |
*/ |
void scale(SkScalar sx, SkScalar sy); |
- /** Preconcat the current matrix with the specified rotation. |
+ /** Preconcat the current matrix with the specified rotation about the origin. |
*/ |